"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const chalk_1 = require("chalk");
const cli_ux_1 = tslib_1.__importDefault(require("cli-ux"));
const command_1 = require("@oclif/command");
const command_2 = tslib_1.__importDefault(require("../../lib/command"));
const aliases_1 = tslib_1.__importDefault(require("../../common/constants/aliases"));
class Login extends command_2.default {
    async execute() {
        cli_ux_1.default.action.start(chalk_1.blue('Starting login process'));
        const { flags: flagsData } = this.parse(Login);
        const device = this.config.userAgent;
        if (Object.keys(flagsData).length) {
            await this.codestore.loginWithEmailAndPassword(flagsData.email, flagsData.password, device);
        }
        else {
            await this.codestore.loginWeb(device);
        }
        await this.resetApiClient();
        const user = await this.codestore.User.getMe();
        cli_ux_1.default.action.stop(chalk_1.blue('Done'));
        this.log(chalk_1.blue(`👋 Welcome to code.store${user.firstName ? `, dear ${user.firstName}` : ''}`));
    }
}
exports.default = Login;
Login.description = 'Authenticate at code.store platform';
Login.aliases = [aliases_1.default.LOGIN];
Login.hidden = false;
Login.usage = aliases_1.default.LOGIN;
Login.flags = Object.assign(Object.assign({}, command_2.default.flags), { email: command_1.flags.string({
        char: 'e',
        description: 'Email',
        dependsOn: ['password'],
    }), password: command_1.flags.string({
        char: 'p',
        description: 'Password',
        dependsOn: ['email'],
    }) });
