"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const chalk_1 = tslib_1.__importDefault(require("chalk"));
const command_1 = tslib_1.__importDefault(require("../../lib/command"));
const aliases_1 = tslib_1.__importDefault(require("../../common/constants/aliases"));
const errors_1 = require("../../lib/errors");
class Whoami extends command_1.default {
    async execute() {
        var _a;
        try {
            const user = await this.codestore.User.getMe();
            let welcomeMessage = "You're ";
            if (user.firstName) {
                welcomeMessage += `${chalk_1.default.cyan(user.firstName)},`;
            }
            if (user.lastName) {
                welcomeMessage += ` officially ${chalk_1.default.cyan(user.lastName)},`;
            }
            welcomeMessage += ` using ${chalk_1.default.cyan(user.email)} as main email`;
            if ((_a = user === null || user === void 0 ? void 0 : user.organization) === null || _a === void 0 ? void 0 : _a.name) {
                welcomeMessage += ` and working for ${chalk_1.default.cyan(user.organization.name)}`;
            }
            welcomeMessage += ". Oh, and you're amazing!";
            this.log(welcomeMessage);
        }
        catch (error) {
            if (error.message === 'GraphQL error: Bad JWT token.') {
                throw new errors_1.NotAuthorizedError();
            }
            this.error(error.message);
        }
    }
}
exports.default = Whoami;
Whoami.description = 'Display the currently logged in user';
Whoami.aliases = [aliases_1.default.WHOAMI];
Whoami.usage = aliases_1.default.WHOAMI;
