"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const command_1 = require("@oclif/command");
const inquirer_1 = tslib_1.__importDefault(require("inquirer"));
const db_command_1 = tslib_1.__importDefault(require("../../lib/db.command"));
class Drop extends db_command_1.default {
    async execute() {
        const { flags: flagsData } = this.parse(Drop);
        const restart = (flagsData === null || flagsData === void 0 ? void 0 : flagsData.restart) || false;
        const db = await super.getDb(flagsData);
        if (!db) {
            return;
        }
        const { environment, service, project } = db;
        if (!flagsData.force) {
            const confirmed = (await inquirer_1.default.prompt([{
                    name: 'result',
                    message: 'Are you sure you want to drop the DB?',
                    type: 'confirm',
                    default: false,
                }])).result;
            if (!confirmed) {
                return;
            }
        }
        this.log('Dropping the DB...');
        await this.codestore.Database.drop(service.id, environment, project.id, restart);
        this.log('The DB has been dropped successfully!');
        if (restart) {
            this.log('Waiting for the service to restart...');
            await this.codestore.Deployment.checkDeployment(service.id, environment, project.id);
            this.log('The service has restarted!');
        }
    }
}
exports.default = Drop;
Drop.flags = Object.assign(Object.assign({}, db_command_1.default.flags), { restart: command_1.flags.boolean({
        char: 'r',
        description: 'Restart the service',
    }), force: command_1.flags.boolean({
        char: 'f',
        description: 'Force',
    }) });
Drop.description = 'Drop the service\'s database';
