"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const chalk_1 = require("chalk");
const codestore_utils_1 = require("codestore-utils");
const path_1 = require("path");
const db_command_1 = tslib_1.__importDefault(require("../../lib/db.command"));
class Export extends db_command_1.default {
    async execute() {
        const { flags: flagsData, args: { table, path } } = this.parse(Export);
        const db = await super.getDb(flagsData);
        if (!db) {
            return;
        }
        const { environment, service, project } = db;
        this.log(`Exporting the table ${chalk_1.blue(table)}...`);
        const res = await this.codestore.Database.exportTable(service.id, environment, project.id, table);
        const dirName = path_1.join(codestore_utils_1.PathsResolverTool.ROOT, path || '');
        await codestore_utils_1.PromisifiedFs.createFolderIfNotExist(dirName);
        const fileName = path_1.join(dirName, `${table}.csv`);
        await codestore_utils_1.PromisifiedFs.writeFile(fileName, res, 'utf8');
        this.log(`The table's csv has been saved to ${fileName}`);
    }
}
exports.default = Export;
Export.flags = Object.assign({}, db_command_1.default.flags);
Export.args = [
    { name: 'table', required: true, description: '(required) Table name' },
    { name: 'path', required: false, description: '(optional) Relative path from the service\'s root to a folder where the csv file will be saved' },
];
Export.description = 'Export a table from the service\'s database';
