"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const command_1 = require("@oclif/command");
const inquirer_1 = tslib_1.__importDefault(require("inquirer"));
const chalk_1 = tslib_1.__importDefault(require("chalk"));
const create_command_1 = tslib_1.__importDefault(require("../../lib/create.command"));
const generation_type_enum_1 = tslib_1.__importDefault(require("../../common/constants/generation-type.enum"));
class Handler extends create_command_1.default {
    constructor() {
        super(...arguments);
        this.availableTypes = [
            generation_type_enum_1.default.AUTH,
            generation_type_enum_1.default.CONTEXT,
        ];
    }
    async execute() {
        let handlerType;
        const { flags: flagsData } = this.parse(Handler);
        if (this.flagsLength(flagsData)) {
            const { handlerType: value } = flagsData;
            handlerType = value;
        }
        else {
            handlerType = await this.getFromPrompt();
        }
        const path = await this.generate(handlerType, flagsData.force);
        if (path) {
            this.log(`File ${chalk_1.default.bold(path)} has been generated.`);
        }
    }
    async getFromPrompt() {
        const { handlerType } = await inquirer_1.default.prompt([
            {
                name: 'handlerType',
                message: 'Select the type of resolver',
                type: 'list',
                choices: this.availableTypes,
            },
        ]);
        return handlerType;
    }
}
exports.default = Handler;
Handler.description = 'Generates auth.handler or context.handler';
Handler.flags = Object.assign(Object.assign({}, create_command_1.default.flags), { handlerType: command_1.flags.string({
        char: 't',
        description: `Handler type, can be one of: ${generation_type_enum_1.default.CONTEXT}, ${generation_type_enum_1.default.AUTH}.`,
        options: [generation_type_enum_1.default.CONTEXT, generation_type_enum_1.default.AUTH],
    }), force: command_1.flags.boolean({
        char: 'f',
        description: 'Force overwrite file if it already exists',
        dependsOn: ['handlerType'],
    }) });
