"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const command_1 = require("@oclif/command");
const inquirer_1 = tslib_1.__importDefault(require("inquirer"));
const chalk_1 = tslib_1.__importDefault(require("chalk"));
const promisified_fs_tool_1 = tslib_1.__importDefault(require("codestore-utils/lib/tool/promisified-fs.tool"));
const create_command_1 = tslib_1.__importDefault(require("../../lib/create.command"));
const generation_type_enum_1 = tslib_1.__importDefault(require("../../common/constants/generation-type.enum"));
class Middleware extends create_command_1.default {
    constructor() {
        super(...arguments);
        this.availableTypes = [
            generation_type_enum_1.default.RESPONSE,
            generation_type_enum_1.default.REQUEST,
        ];
    }
    async execute() {
        var _a, _b;
        let middlewareData;
        const { flags: flagsData } = this.parse(Middleware);
        const { rest } = await this.serviceWorker.loadValuesFromYaml();
        if (!rest) {
            throw new Error('REST property not declared in codestore.yaml');
        }
        if (this.flagsLength(flagsData)) {
            const { position, name, route } = flagsData;
            if (!((_a = rest.routes) === null || _a === void 0 ? void 0 : _a.find((r) => r.path === route))) {
                throw new Error(`Route ${route} not found, please check codestore.yaml`);
            }
            middlewareData = {
                position: position,
                name: name,
                route: route,
            };
        }
        else {
            middlewareData = await this.getFromPrompt(((_b = rest.routes) === null || _b === void 0 ? void 0 : _b.map((it) => it.path)) || []);
        }
        const middlewareName = `${middlewareData.name}.middleware`;
        const path = await this.generate(generation_type_enum_1.default.MIDDLEWARE, flagsData.force, middlewareName);
        if (path) {
            try {
                const mwPathName = path.split('/src')[1].replace('.ts', '');
                await this.serviceWorker.applyMiddleware(middlewareData.route, middlewareData.position, mwPathName);
                this.log(`File ${chalk_1.default.bold(path)} has been generated.`);
            }
            catch (e) {
                await promisified_fs_tool_1.default.unlink(path);
                throw e;
            }
        }
    }
    async getFromPrompt(routeList) {
        if (!routeList.length) {
            throw new Error('You have no created routes. Please describe it in codestore.yaml');
        }
        return inquirer_1.default.prompt([
            {
                name: 'position',
                message: 'Select position of middleware',
                type: 'list',
                choices: this.availableTypes,
            },
            {
                name: 'name',
                message: 'Enter name of your middleware',
            },
            {
                name: 'route',
                message: 'Select route to apply',
                type: 'list',
                choices: routeList,
            },
        ]);
    }
}
exports.default = Middleware;
Middleware.description = 'Generates request or response middleware';
Middleware.flags = Object.assign(Object.assign({}, create_command_1.default.flags), { position: command_1.flags.string({
        char: 'p',
        description: `Middleware position, can be one of: ${generation_type_enum_1.default.REQUEST}, ${generation_type_enum_1.default.RESPONSE}.`,
        options: [generation_type_enum_1.default.REQUEST, generation_type_enum_1.default.RESPONSE],
    }), name: command_1.flags.string({
        char: 'n',
        description: 'Name of the middleware',
        dependsOn: ['position', 'route'],
    }), route: command_1.flags.string({
        char: 'r',
        description: 'Route to middleware will be applied on',
        dependsOn: ['position', 'name'],
    }), force: command_1.flags.boolean({
        char: 'f',
        description: 'Force overwrite file if it already exists',
        dependsOn: ['position', 'name', 'route'],
    }) });
