"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const command_1 = require("@oclif/command");
const codestore_utils_1 = require("codestore-utils");
const listr2_1 = require("listr2");
const path_1 = require("path");
const logFiles_1 = tslib_1.__importDefault(require("../../common/constants/logFiles"));
const file_worker_1 = tslib_1.__importDefault(require("../../common/file-worker"));
const command_2 = tslib_1.__importDefault(require("../../lib/command"));
const errors_1 = require("../../lib/errors");
const service_worker_1 = tslib_1.__importDefault(require("../../lib/service-worker"));
class Models extends command_2.default {
    async execute() {
        var _a;
        const path = path_1.join(codestore_utils_1.PathsResolverTool.ROOT, ((_a = this.parse(Models).flags) === null || _a === void 0 ? void 0 : _a.path) || 'generatedData');
        const tasks = new listr2_1.Listr([
            {
                title: 'Reading the service schema',
                task: async (ctx) => {
                    ctx.schema = await codestore_utils_1.PromisifiedFs.readFile(codestore_utils_1.PathsResolverTool.SCHEMA, { encoding: 'utf8' });
                },
            },
            {
                title: 'Uploading the service schema to the generator',
                task: async (ctx) => {
                    const { schema } = ctx;
                    ctx.generated = await this.codestore.Service.generateEntities(schema);
                },
            },
            {
                title: 'Saving generated code',
                task: async (ctx, task) => {
                    const { generated } = ctx;
                    const logPath = await service_worker_1.default.writeLog(logFiles_1.default.GENERATION, generated.logs.join('\n'));
                    if (!generated.data) {
                        throw new errors_1.GeneratorError(generated.logs, logPath);
                    }
                    await codestore_utils_1.PromisifiedFs.rimraf(path);
                    await codestore_utils_1.PromisifiedFs.createFolderIfNotExist(path);
                    await file_worker_1.default.saveZipFromB64(generated.data, path);
                    task.title = `Generated code has been saved to ${path_1.relative(codestore_utils_1.PathsResolverTool.ROOT, path)}`;
                },
            },
        ]);
        await tasks.run();
    }
}
exports.default = Models;
Models.description = 'Generates database entities and a migration';
Models.flags = Object.assign(Object.assign({}, command_2.default.flags), { path: command_1.flags.string({
        char: 'p',
        description: 'Relative path from the service\'s root to a folder where generated files will be saved',
    }) });
