"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const command_1 = require("@oclif/command");
const inquirer_1 = tslib_1.__importDefault(require("inquirer"));
const resolver_type_enum_1 = tslib_1.__importDefault(require("../../common/constants/resolver-type.enum"));
const create_command_1 = tslib_1.__importDefault(require("../../lib/create.command"));
class Resolver extends create_command_1.default {
    async execute() {
        let data;
        const { flags: flagsData } = this.parse(Resolver);
        if (Object.keys(flagsData).length >= 2) {
            data = {
                resolverType: flagsData.resolverType,
                name: flagsData.name,
            };
        }
        else {
            data = await this.getFromPrompt();
        }
        const { resolverType, name } = data;
        await this.generate(resolverType, flagsData.force, name);
    }
    async getFromPrompt() {
        const { resolverType, name } = await inquirer_1.default.prompt([
            {
                name: 'resolverType',
                message: 'Select the type of resolver',
                type: 'list',
                choices: Object.values(resolver_type_enum_1.default),
            },
            {
                name: 'name',
                message: 'Enter the name of your resolver',
                validate: (value) => this.validate('name', value),
            },
        ]);
        return {
            resolverType,
            name,
        };
    }
    get rules() {
        return {
            name: (value) => {
                if (!value) {
                    return 'Name is required';
                }
                return true;
            },
        };
    }
}
exports.default = Resolver;
Resolver.description = 'Generates a GraphQL resolver';
Resolver.flags = Object.assign(Object.assign({}, create_command_1.default.flags), { resolverType: command_1.flags.string({
        char: 't',
        description: `Resolver type, one of: '${resolver_type_enum_1.default.QUERY}' or '${resolver_type_enum_1.default.MUTATION}'`,
        options: [resolver_type_enum_1.default.QUERY, resolver_type_enum_1.default.MUTATION],
        dependsOn: ['name'],
    }), name: command_1.flags.string({
        char: 'n',
        description: 'Resolver name',
        dependsOn: ['resolverType'],
    }), force: command_1.flags.boolean({
        char: 'f',
        description: 'Force overwrite file if it already exists',
        dependsOn: ['resolverType', 'name'],
    }) });
