"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const command_1 = require("@oclif/command");
const inquirer_1 = tslib_1.__importDefault(require("inquirer"));
const generation_type_enum_1 = tslib_1.__importDefault(require("../../common/constants/generation-type.enum"));
const http_method_enum_1 = tslib_1.__importDefault(require("../../common/constants/http-method.enum"));
const create_command_1 = tslib_1.__importDefault(require("../../lib/create.command"));
class Rest extends create_command_1.default {
    async execute() {
        let data;
        const { flags: flagsData } = this.parse(Rest);
        if (Object.keys(flagsData).length) {
            data = { method: flagsData.method, name: flagsData.name };
        }
        else {
            data = await Rest.getFromPrompt();
        }
        const endpointNameWithMethod = `${data.method}.${data.name}`;
        await this.generate(generation_type_enum_1.default.ENDPOINT, flagsData.force, endpointNameWithMethod);
    }
    static async getFromPrompt() {
        const { method, name } = await inquirer_1.default.prompt([
            {
                name: 'method',
                message: 'Select HTTP method',
                type: 'list',
                choices: Object.keys(http_method_enum_1.default),
            },
            {
                name: 'name',
                message: 'Name of your REST endpoint',
            },
        ]);
        return {
            method: http_method_enum_1.default[method], name,
        };
    }
    get rules() {
        return {
            name: (value) => {
                if (!value) {
                    return 'Name is required';
                }
                return true;
            },
        };
    }
}
exports.default = Rest;
Rest.description = 'Generates a REST API handler';
Rest.flags = Object.assign(Object.assign({}, create_command_1.default.flags), { method: command_1.flags.string({
        char: 'm',
        description: `HTTP method, one of: ${Object.values(http_method_enum_1.default).join(', ')}`,
        options: Object.values(http_method_enum_1.default),
        dependsOn: ['name'],
    }), name: command_1.flags.string({
        char: 'n',
        description: 'REST endpoint name',
        dependsOn: ['method'],
    }), force: command_1.flags.boolean({
        char: 'f',
        description: 'Force overwrite file if it already exists',
        dependsOn: ['method', 'name'],
    }) });
