"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const inquirer_1 = tslib_1.__importDefault(require("inquirer"));
const chalk_1 = require("chalk");
const command_1 = tslib_1.__importDefault(require("../../../lib/command"));
const utils_1 = require("../../../common/utils");
class Remove extends command_1.default {
    async execute() {
        let client;
        const { args: { clientArg, projectArg } } = this.parse(Remove);
        const project = await this.chooseProject({ projectArg });
        if (!project) {
            return;
        }
        const clients = await this.codestore.Project.listClientsByUniqueName(project.uniqueName);
        if (!(clients === null || clients === void 0 ? void 0 : clients.length)) {
            this.log(`There are no clients yet, try adding one using ${chalk_1.yellow('codestore project:clients:add')} command.`);
            return;
        }
        if (clientArg) {
            client = clients.find((c) => c.email === clientArg);
            if (!client) {
                this.log(`Client with email: ${chalk_1.blue(clientArg)} not found.`);
            }
        }
        if (!client) {
            const clientsMap = new Map(clients.map((c) => [`${c.email}\t`, c]));
            const { choosedClient } = await inquirer_1.default.prompt({
                type: 'list',
                name: 'choosedClient',
                message: 'Clients:',
                prefix: utils_1.createPrefix('Choose a client'),
                choices: Array.from(clientsMap.keys()),
            });
            client = clientsMap.get(choosedClient);
        }
        if (!client) {
            return;
        }
        await this.codestore.Project.deleteClient(Number(client.id));
        this.log(`Client with email: ${chalk_1.blue(client.email)} successfully removed!`);
    }
}
exports.default = Remove;
Remove.description = 'Remove access to the project';
Remove.args = [
    { name: 'projectArg', description: 'ID of the project' },
    { name: 'clientArg', description: 'Email of the client' },
];
