"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const command_1 = require("@oclif/command");
const chalk_1 = require("chalk");
const inquirer_1 = tslib_1.__importDefault(require("inquirer"));
const listr2_1 = require("listr2");
const string_length_enum_1 = tslib_1.__importDefault(require("../../common/constants/string.length.enum"));
const utils_1 = require("../../common/utils");
const command_2 = tslib_1.__importDefault(require("../../lib/command"));
class Create extends command_2.default {
    async execute() {
        let data;
        const { flags: flagsData } = this.parse(Create);
        if (this.flagsLength(flagsData)) {
            data = Object.assign(Object.assign({}, await this.validateFlags(Create.flags, flagsData)), { proceed: true });
        }
        else {
            const questions = this.getQuestions();
            data = await inquirer_1.default.prompt(questions);
        }
        const { proceed, name, description } = data;
        if (!proceed) {
            this.log('Project has not been created');
            return;
        }
        const tasks = new listr2_1.Listr([{
                title: `Creating Project "${chalk_1.bold(name)}"`,
                task: async (ctx, task) => {
                    const { uniqueName, name: projectName, developerKey } = await this.codestore.Project.create({ name, description });
                    task.title = `Your project "${chalk_1.bold(projectName)}" with ID ${chalk_1.blue(uniqueName)} has been created!`;
                    task.output = `You can now add your services there using ${chalk_1.yellow(' codestore project:service ')} command.
Use your developer key to access developer and stage environments: ${chalk_1.bold(developerKey)}`;
                },
                options: { persistentOutput: true },
            }]);
        await tasks.run();
    }
    get rules() {
        return {
            description: (value) => {
                const name = 'Description';
                if (!value) {
                    return `${name} is required`;
                }
                if (value.length > string_length_enum_1.default.MAX) {
                    return `${name} should be less than ${string_length_enum_1.default.MAX} characters`;
                }
                return true;
            },
            name: (value) => {
                const name = 'Project name';
                if (!value) {
                    return `${name} is required`;
                }
                if (value.length >= string_length_enum_1.default.MEDIUM) {
                    return `${name} should be less than ${string_length_enum_1.default.MEDIUM} characters`;
                }
                if (value.length < string_length_enum_1.default.MIN) {
                    return `${name} must be longer than or equal to ${string_length_enum_1.default.MIN} characters`;
                }
                return true;
            },
        };
    }
    getQuestions() {
        return [{
                name: 'name',
                message: 'Name:',
                validate: (value) => this.validate('name', value),
                prefix: utils_1.createPrefix('What is your project\'s name?'),
                type: 'input',
            }, {
                name: 'description',
                message: 'Description:',
                validate: (value) => this.validate('description', value),
                prefix: utils_1.createPrefix(`Please add a short description of your project. ${string_length_enum_1.default.MAX} chars max`),
                type: 'input',
            }, {
                name: 'proceed',
                message: 'Is everything ok, can I create this project?',
                type: 'confirm',
            }];
    }
}
exports.default = Create;
Create.description = 'Creates a new project, where you can add services';
Create.flags = Object.assign(Object.assign({}, command_2.default.flags), { name: command_1.flags.string({
        char: 'n',
        description: 'Project name',
    }), description: command_1.flags.string({
        char: 'd',
        description: `A short description of your project. ${string_length_enum_1.default.MAX} chars max.`,
    }) });
