"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const command_1 = require("@oclif/command");
const chalk_1 = require("chalk");
const inquirer_1 = tslib_1.__importDefault(require("inquirer"));
const listr2_1 = require("listr2");
const command_2 = tslib_1.__importDefault(require("../../lib/command"));
class Delete extends command_2.default {
    async execute() {
        const { args: { project_id: projectId }, flags: { force } } = this.parse(Delete);
        let confirmed = force;
        const project = await this.codestore.Project.singleByUniqueName(projectId);
        if (!project) {
            this.log('Seems like you are trying to remove project that not exist');
            return;
        }
        if (!confirmed) {
            confirmed = (await inquirer_1.default.prompt([{
                    name: 'result',
                    message: `Are you sure you want to delete project ${chalk_1.yellow(project.name)} (ID = ${chalk_1.yellow(project.uniqueName)}) ?`,
                    type: 'confirm',
                    default: false,
                }])).result;
        }
        if (confirmed) {
            const tasks = new listr2_1.Listr([{
                    title: `Removing project ${chalk_1.yellow(projectId)}`,
                    task: async (_, task) => {
                        await this.codestore.Project.delete(project.id);
                        task.title = `Your project ${chalk_1.yellow(project.name)} with ID = ${chalk_1.yellow(project.uniqueName)} doesn't exist anymore.`;
                    },
                }]);
            await tasks.run();
        }
        else {
            this.log(`Your project ${chalk_1.yellow(project.name)} with ID = ${chalk_1.yellow(project.uniqueName)} was not removed. It's still here. No worries.`);
        }
    }
}
exports.default = Delete;
Delete.description = 'Removes the project (only if there are no more services inside)';
Delete.args = [
    { name: 'project_id', required: true, description: '(required) ID of the project' },
];
Delete.flags = Object.assign(Object.assign({}, command_2.default.flags), { force: command_1.flags.boolean({
        char: 'f',
        default: false,
    }) });
