"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const command_1 = require("@oclif/command");
const chalk_1 = require("chalk");
const environment_enum_1 = require("../../../common/constants/environment.enum");
const command_2 = tslib_1.__importDefault(require("../../../lib/command"));
const ServiceInfo = tslib_1.__importStar(require("../../service/info"));
class Info extends command_2.default {
    async execute() {
        const { args, flags: flagsData } = this.parse(Info);
        let project;
        let service;
        if (this.flagsLength(flagsData)) {
            const data = await this.validateFlags(Info.flags, flagsData);
            project = await this.findProject(data.project);
            if (!project) {
                this.error(`Project with id ${chalk_1.blue(data.project)} does not exist`);
            }
            const { projectServices } = await this.codestore.Project.single(project.id, true);
            if (!(projectServices === null || projectServices === void 0 ? void 0 : projectServices.length)) {
                this.log(`There are no services in the selected project. Try to add a new one using ${chalk_1.yellow('codestore project:service:add')} command.`);
                return;
            }
            service = await this.findService(data.service, projectServices.map((ps) => ps.service));
            if (!service) {
                this.error(`Service with id ${chalk_1.blue(data.service)} does not exist`);
            }
        }
        else {
            project = await this.chooseProject(args, 'Choose which project you want to display information about');
            if (!project)
                return;
            const { projectServices } = await this.codestore.Project.single(project.id, true);
            if (!(projectServices === null || projectServices === void 0 ? void 0 : projectServices.length)) {
                this.log(`There are no services in the selected project. Try to add a new one using ${chalk_1.yellow('codestore project:service:add')} command.`);
                return;
            }
            service = await this.chooseService(args, 'Choose which service you want to display information about', projectServices.map((ps) => ps.service));
        }
        if (!service)
            return;
        const deployments = await this.codestore.Deployment.getDeploymentsForProjectService(project.id, service.id);
        const deploymentTo = ServiceInfo.deploymentsToEnvironments(deployments, environment_enum_1.projectServiceEnvironments);
        const createRows = (fields) => fields.map(({ name, resolve }) => {
            const result = { name };
            environment_enum_1.projectServiceEnvironments.forEach((environment) => {
                if (deploymentTo[environment]) {
                    result[environment] = resolve(deploymentTo[environment]);
                }
            });
            return result;
        });
        this.renderTable(createRows(ServiceInfo.getFieldResolvers()), ServiceInfo.createColumns(environment_enum_1.projectServiceEnvironments, deploymentTo));
    }
    get rules() {
        return {
            service: (value) => {
                if (!value) {
                    return 'ID of the service is required';
                }
                return true;
            },
            project: (value) => {
                if (!value) {
                    return 'ID of the project is required';
                }
                return true;
            },
        };
    }
}
exports.default = Info;
Info.description = 'Displays detailed information about project\'s service';
Info.args = [
    { name: 'projectArg', description: 'ID of the project' },
    { name: 'serviceArg', description: 'ID of the service' },
];
Info.flags = Object.assign(Object.assign({}, command_2.default.flags), { project: command_1.flags.string({
        char: 'p',
        description: 'ID of the project',
    }), service: command_1.flags.string({
        char: 's',
        description: 'ID of the service',
    }) });
