"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const chalk_1 = require("chalk");
const cli_ux_1 = tslib_1.__importDefault(require("cli-ux"));
const aliases_1 = tslib_1.__importDefault(require("../../../common/constants/aliases"));
const environment_enum_1 = tslib_1.__importDefault(require("../../../common/constants/environment.enum"));
const command_1 = tslib_1.__importDefault(require("../../../lib/command"));
class List extends command_1.default {
    constructor() {
        super(...arguments);
        this.mapData = (project) => {
            var _a, _b, _c;
            const development = (_a = project.environments) === null || _a === void 0 ? void 0 : _a.find((e) => e.name === environment_enum_1.default.DEVELOPMENT);
            const staging = (_b = project.environments) === null || _b === void 0 ? void 0 : _b.find((e) => e.name === environment_enum_1.default.STAGING);
            const production = (_c = project.environments) === null || _c === void 0 ? void 0 : _c.find((e) => e.name === environment_enum_1.default.PRODUCTION);
            const versionName = (env, serviceId) => { var _a, _b, _c; return (_c = (_b = (_a = env === null || env === void 0 ? void 0 : env.deployments) === null || _a === void 0 ? void 0 : _a.find((deployment) => deployment.serviceId === serviceId)) === null || _b === void 0 ? void 0 : _b.version) === null || _c === void 0 ? void 0 : _c.name; };
            return project.projectServices.map(({ service }) => ({
                id: service.uniqueName,
                name: service.displayName,
                development: versionName(development, service.id),
                staging: versionName(staging, service.id),
                production: versionName(production, service.id),
            }));
        };
    }
    async execute() {
        const { args: { project_id: projectUniqueName } } = this.parse(List);
        const project = await this.codestore.Project.singleWithEnvsByUniqueName(projectUniqueName);
        if (!project) {
            this.log(`There is no project with ID ${chalk_1.blue(projectUniqueName)}`);
            return;
        }
        cli_ux_1.default.table(this.mapData(project), {
            id: {
                header: 'Service ID',
            },
            name: {},
            development: {},
            staging: {},
            production: {},
        }, { 'no-truncate': true });
    }
}
exports.default = List;
List.description = 'Lists services in your project';
List.aliases = [aliases_1.default.PROJECT_SERVICE_LS];
List.args = [
    { name: 'project_id', required: true, description: '(required) ID of the project' },
];
