"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const command_1 = require("@oclif/command");
const chalk_1 = require("chalk");
const command_2 = tslib_1.__importDefault(require("../../../lib/command"));
const environment_enum_1 = tslib_1.__importDefault(require("../../../common/constants/environment.enum"));
class Roll extends command_2.default {
    async execute() {
        var _a;
        const { args, flags: flagsData } = this.parse(Roll);
        let project;
        let service;
        let commitId;
        if (this.flagsLength(flagsData)) {
            const data = await this.validateFlags(Roll.flags, flagsData);
            project = await this.findProject(data.project);
            if (!project) {
                this.error(`Project with id ${chalk_1.blue(data.project)} does not exist`);
            }
            service = await this.findService(data.service, project.projectServices.map((ps) => ps.service));
            if (!service) {
                this.error(`Service with id ${chalk_1.blue(data.service)} does not exist in project ${chalk_1.blue(project.uniqueName)}`);
            }
            const version = service.versions.find((v) => v.name === flagsData.version);
            if (!version) {
                this.error(`Version with name ${chalk_1.blue(flagsData.version)} was not found in service ${chalk_1.blue(service.uniqueName)}`);
            }
            commitId = version.commitId;
        }
        else {
            project = await this.chooseProject(args, 'Choose a project you want to promote to');
            if (!project)
                return;
            service = await this.chooseService(args, 'Choose a service which you want to promote', project.projectServices.map((ps) => ps.service));
            if (!service)
                return;
            commitId = (_a = (await this.chooseVersion(service))) === null || _a === void 0 ? void 0 : _a.commitId;
        }
        const projectUniqueName = project.uniqueName;
        const serviceUniqueName = service.uniqueName;
        this.log();
        try {
            await this.codestore.Project.roll({
                serviceId: service.id,
                projectId: project.id,
                commitId,
            });
            this.log(`Updated "${chalk_1.bold(environment_enum_1.default.DEVELOPMENT)}" in project ${chalk_1.blue(projectUniqueName)}`);
        }
        catch (error) {
            if (error.message.match(/is up to date/)) {
                this.log(`\n"${chalk_1.bold(environment_enum_1.default.DEVELOPMENT)}" environment of service ${chalk_1.blue(serviceUniqueName)} is up to date`);
            }
        }
    }
    get rules() {
        return {
            service: (value) => {
                if (!value) {
                    return 'ID of the service is required';
                }
                return true;
            },
            project: (value) => {
                if (!value) {
                    return 'ID of the project is required';
                }
                return true;
            },
            version: (value) => {
                if (!value) {
                    return 'Version is required';
                }
                return true;
            },
        };
    }
}
exports.default = Roll;
Roll.description = `Updates Development environment inside the project to selected version.
Run without arguments to select project, service and version from a list.`;
Roll.flags = Object.assign(Object.assign({}, command_2.default.flags), { project: command_1.flags.string({
        char: 'p',
        description: 'ID of the project',
    }), service: command_1.flags.string({
        char: 's',
        description: 'ID of the service',
    }), version: command_1.flags.string({
        char: 'v',
        description: 'Version of the service',
    }) });
Roll.args = [
    { name: 'projectArg', description: 'ID of the project' },
    { name: 'serviceArg', description: 'ID of the service' },
];
