"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const command_1 = require("@oclif/command");
const inquirer_1 = tslib_1.__importDefault(require("inquirer"));
const chalk_1 = require("chalk");
const base_secret_command_1 = tslib_1.__importDefault(require("../../common/base-secret-command"));
const environment_enum_1 = require("../../common/constants/environment.enum");
class Add extends base_secret_command_1.default {
    async execute() {
        const { flags: flagsData } = this.parse(Add);
        let projectUniqueName;
        let serviceUniqueName;
        let key;
        let value;
        let environment;
        if (Object.keys(flagsData).length) {
            projectUniqueName = flagsData.projectUniqueName;
            serviceUniqueName = flagsData.serviceUniqueName;
            environment = flagsData.environment;
            key = flagsData.key;
            value = flagsData.value;
        }
        else {
            const project = await this.chooseProject({}, 'Choose a project if you want to apply secret to project environments or "-" for service environments', true);
            const services = (project === null || project === void 0 ? void 0 : project.projectServices.map((ps) => ps.service)) || (await this.codestore.Service.list());
            if (!services.length) {
                this.log('You don\'t have any services yet. Try creating one by running `codestore service:create`.');
                return;
            }
            serviceUniqueName = ((await this.chooseService({}, '', services))).uniqueName;
            projectUniqueName = project === null || project === void 0 ? void 0 : project.uniqueName;
            environment = await this.chooseEnvironment(project ? environment_enum_1.projectServiceEnvironments : environment_enum_1.serviceEnvironments);
            key = (await inquirer_1.default.prompt([{
                    name: 'key',
                    message: 'Key',
                }])).key;
            value = (await inquirer_1.default.prompt([{
                    name: 'value',
                    message: 'Value',
                }])).value;
        }
        base_secret_command_1.default.isSecretCommandValid(projectUniqueName, serviceUniqueName, environment);
        if (!(key && value)) {
            this.log(`Please, provide ${chalk_1.blue('key')} and ${chalk_1.blue('value')}.`);
            return;
        }
        const values = {
            projectUniqueName,
            serviceUniqueName,
            environment,
            key,
            value,
        };
        const secrets = await this.codestore.Secret.add(values).catch((e) => this.error(e.message));
        if (!secrets) {
            this.log(`Failed to add secret variable ${chalk_1.blue(key)}`);
            return;
        }
        this.log(`Successfully added a new secret variable ${chalk_1.blue(key)}`);
        base_secret_command_1.default.renderSecrets(secrets);
    }
}
exports.default = Add;
Add.description = 'Add a new secret variable to your service';
Add.flags = Object.assign(Object.assign({}, base_secret_command_1.default.defaultFlags), { key: command_1.flags.string({
        char: 'k',
        dependsOn: ['value'],
        description: 'Secret variable name',
    }), value: command_1.flags.string({
        char: 'v',
        dependsOn: ['key'],
        description: 'Secret variable value',
    }) });
