"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const command_1 = require("@oclif/command");
const chalk_1 = require("chalk");
const base_secret_command_1 = tslib_1.__importDefault(require("../../common/base-secret-command"));
class Remove extends base_secret_command_1.default {
    async execute() {
        const { flags: { projectUniqueName, serviceUniqueName, environment, key, }, } = this.parse(Remove);
        base_secret_command_1.default.isSecretCommandValid(projectUniqueName, serviceUniqueName, environment);
        const values = {
            projectUniqueName, serviceUniqueName, environment, key,
        };
        const secrets = await this.codestore.Secret.remove(values);
        if (!secrets) {
            this.log(`Failed to remove secret variable ${chalk_1.blue(key)}`);
            return;
        }
        this.log(`Successfully removed secret variable ${chalk_1.blue(key)}`);
        base_secret_command_1.default.renderSecrets(secrets);
    }
}
exports.default = Remove;
Remove.description = 'Remove secret variable from your service';
Remove.flags = Object.assign(Object.assign({}, base_secret_command_1.default.defaultFlags), { key: command_1.flags.string({
        char: 'k',
        required: true,
        description: 'Secret variable name',
    }) });
