"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const command_1 = require("@oclif/command");
const command_2 = tslib_1.__importDefault(require("../../lib/command"));
const typescript_1 = tslib_1.__importDefault(require("../../common/launchers/typescript"));
const golang_1 = tslib_1.__importDefault(require("../../common/launchers/golang"));
const template_enum_1 = tslib_1.__importDefault(require("../../common/constants/template.enum"));
class Dev extends command_2.default {
    constructor() {
        super(...arguments);
        this.templates = {
            [template_enum_1.default.Typescript]: (opts) => new typescript_1.default(opts.watch, opts.database, opts.port),
            [template_enum_1.default.Golang]: (opts) => new golang_1.default(opts.database, opts.port),
        };
    }
    async execute() {
        const { localConfiguration, template } = await this.serviceWorker.loadValuesFromYaml();
        const { flags: { watch } } = this.parse(Dev);
        await this.templates[template]({
            watch,
            database: localConfiguration.database,
            port: localConfiguration.application.port,
        }).bootstrap();
    }
}
exports.default = Dev;
Dev.description = 'Launch your service locally';
Dev.aliases = ['dev'];
Dev.flags = Object.assign(Object.assign({}, command_2.default.flags), { watch: command_1.flags.boolean({
        char: 'w',
        description: 'Starts compilation in watch mode',
        default: false,
    }) });
