"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createColumns = exports.deploymentsToEnvironments = exports.getFieldResolvers = void 0;
const tslib_1 = require("tslib");
const command_1 = require("@oclif/command");
const environment_enum_1 = tslib_1.__importStar(require("../../common/constants/environment.enum"));
const command_2 = tslib_1.__importDefault(require("../../lib/command"));
const versionResolver = (deployment) => (deployment.version ? deployment.version.name : '');
const deployedResolver = (deployment) => new Date(+deployment.updatedAt).toLocaleString();
const urlResolver = (deployment) => command_2.default.getServiceUrl(deployment);
const keyResolver = (_deployment, developerKey = '') => developerKey;
exports.getFieldResolvers = () => [{
        name: 'version',
        resolve: versionResolver,
    }, {
        name: 'deployed',
        resolve: deployedResolver,
    }, {
        name: 'developer key',
        resolve: keyResolver,
    }, {
        name: 'url',
        resolve: urlResolver,
    }];
exports.deploymentsToEnvironments = (deployments, environments) => {
    const result = {};
    environments.forEach((environment) => {
        result[environment] = deployments.find((d) => d.environment.name === environment);
    });
    return result;
};
exports.createColumns = (environments, deployments) => {
    const result = { name: { header: '' } };
    environments.forEach((environment) => {
        if (deployments[environment]) {
            result[environment] = {};
        }
    });
    return result;
};
class Info extends command_2.default {
    async execute() {
        let service;
        const { args, flags: { service: serviceFlag } } = this.parse(Info);
        if (serviceFlag) {
            service = await this.codestore.Service.getServiceByUniqueName(serviceFlag);
            if (!service) {
                this.error(`Service with ID ${serviceFlag} does not exist`);
            }
        }
        else {
            try {
                const { serviceId } = await this.serviceWorker.loadValuesFromYaml();
                service = await this.codestore.Service.getService(serviceId);
            }
            catch (e) {
                service = await this.chooseService(args, 'Choose which service you want to display information about');
            }
        }
        if (!service)
            return;
        const deployments = await this.codestore.Deployment.getDeploymentsForService(service.id);
        const deploymentTo = exports.deploymentsToEnvironments(deployments, environment_enum_1.serviceEnvironments);
        const createRows = (fields) => fields.map(({ name, resolve }) => ({
            name,
            private: resolve(deploymentTo[environment_enum_1.default.PRIVATE], service === null || service === void 0 ? void 0 : service.developerKey),
            demo: resolve(deploymentTo[environment_enum_1.default.DEMO]),
        }));
        this.renderTable(createRows(exports.getFieldResolvers()), exports.createColumns(environment_enum_1.serviceEnvironments, deploymentTo));
    }
}
exports.default = Info;
Info.description = 'Displays detailed information about a service';
Info.args = [
    { name: 'serviceArg', description: 'ID of the service' },
];
Info.flags = Object.assign(Object.assign({}, command_2.default.flags), { service: command_1.flags.string({
        char: 's',
        description: 'ID of the service',
    }) });
