"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const command_1 = require("@oclif/command");
const chalk_1 = require("chalk");
const command_2 = tslib_1.__importDefault(require("../../lib/command"));
const environment_enum_1 = tslib_1.__importDefault(require("../../common/constants/environment.enum"));
const aliases_1 = tslib_1.__importDefault(require("../../common/constants/aliases"));
const logs_1 = require("../../common/constants/logs");
class Logs extends command_2.default {
    constructor() {
        super(...arguments);
        this.logs = [];
    }
    async fetch(query) {
        return this.codestore.Logs.list(query);
    }
    async updateLogs(query) {
        this.logs = await this.fetch(query);
    }
    render() {
        this.logs.forEach((log) => {
            const time = chalk_1.white(new Date(log.time).toISOString());
            const context = log.context ? chalk_1.yellow(`[${log.context.trim()}] `) : '';
            const message = chalk_1.green(log.message.trim());
            this.log(`${time} ${context}${message}`);
        });
    }
    async execute() {
        const _a = this.parse(Logs).flags, { follow } = _a, query = tslib_1.__rest(_a, ["follow"]);
        let { env } = query;
        if (!env)
            env = query.projectUniqueName ? environment_enum_1.default.DEVELOPMENT : environment_enum_1.default.PRIVATE;
        const newQuery = {
            num: query.num,
            env,
            serviceUniqueName: query.serviceUniqueName,
            projectUniqueName: query.projectUniqueName,
        };
        if (!query.serviceUniqueName && !query.projectUniqueName) {
            const { serviceId } = await this.serviceWorker.loadValuesFromYaml();
            newQuery.serviceId = serviceId;
        }
        this.log(`Displaying logs for environment ${env}${query.serviceUniqueName ? `, service ${query.serviceUniqueName}` : ''}${query.projectUniqueName ? `, project ${query.projectUniqueName}` : ''}`);
        await this.updateLogs(newQuery);
        this.render();
        if (follow) {
            setInterval(async () => {
                if (this.logs.length) {
                    newQuery.sinceTime = new Date(this.logs[this.logs.length - 1].time);
                }
                await this.updateLogs(newQuery);
                this.render();
            }, logs_1.FETCH_INTERVAL);
        }
    }
}
exports.default = Logs;
Logs.description = 'Print the logs for your services';
Logs.aliases = [aliases_1.default.LOGS];
Logs.flags = Object.assign(Object.assign({}, command_2.default.flags), { follow: command_1.flags.boolean({
        char: 'f',
        description: 'Specify if the logs should be streamed.',
    }), num: command_1.flags.integer({
        char: 'n',
        description: 'Number of most recent log lines to display.',
        default: logs_1.NUMBER_OF_LINES,
    }), env: command_1.flags.enum({
        char: 'e',
        description: 'Project environment.',
        options: Object.values(environment_enum_1.default),
    }), projectUniqueName: command_1.flags.string({
        char: 'p',
        description: 'Project ID',
    }), serviceUniqueName: command_1.flags.string({
        char: 's',
        description: 'Service ID',
    }) });
