"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const chalk_1 = require("chalk");
const command_1 = tslib_1.__importDefault(require("../../lib/command"));
const errors_1 = require("../../lib/errors");
const aliases_1 = tslib_1.__importDefault(require("../../common/constants/aliases"));
class Promote extends command_1.default {
    async execute() {
        const { args } = this.parse(Promote);
        let { serviceArg: serviceId } = args;
        try {
            if (!serviceId) {
                serviceId = Number((await this.serviceWorker.loadValuesFromYaml()).serviceId);
            }
        }
        catch (error) {
            if (error.constructor === errors_1.WrongFolderError) {
                const service = await this.chooseService(args, 'Choose a service which you want to promote');
                if (!service)
                    return;
                serviceId = service.id;
            }
        }
        try {
            let service;
            if (typeof serviceId === 'string') {
                service = await this.codestore.Service.promoteByUniqueName(serviceId);
            }
            else {
                service = await this.codestore.Service.promote(serviceId);
            }
            this.log(`Successfully promoted service with ID ${chalk_1.blue(service.uniqueName)} to demo environment`);
        }
        catch (error) {
            this.log(error.message);
        }
    }
}
exports.default = Promote;
Promote.description = 'Promotes service from private env to demo';
Promote.args = [
    { name: 'serviceArg', description: 'ID of the service (optional)' },
];
Promote.aliases = [aliases_1.default.PROMOTE];
