"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const command_1 = require("@oclif/command");
const chalk_1 = require("chalk");
const inquirer_1 = tslib_1.__importDefault(require("inquirer"));
const aliases_1 = tslib_1.__importDefault(require("../../common/constants/aliases"));
const file_worker_1 = tslib_1.__importDefault(require("../../common/file-worker"));
const command_2 = tslib_1.__importDefault(require("../../lib/command"));
const errors_1 = require("../../lib/errors");
class Pull extends command_2.default {
    async execute() {
        const parsed = this.parse(Pull);
        let { args: { service_id: serviceId } } = parsed;
        const { flags: { force } } = parsed;
        let confirmed = force;
        if (!serviceId) {
            try {
                serviceId = Number((await this.serviceWorker.loadValuesFromYaml()).serviceId);
            }
            catch (error) {
                if (error.constructor === errors_1.WrongFolderError) {
                    this.log(`You must be in code.store service folder to invoke this command without arguments.
Use ${chalk_1.yellow(' codestore service:pull [SERVICE_ID] ')} command to pull a service which doesn’t exist on your local machine yet.

${chalk_1.red('BE CAREFUL! Any local changes might be deleted and lost')}`);
                }
                return;
            }
        }
        let service;
        if (typeof serviceId === 'string') {
            service = await this.codestore.Service.getServiceByUniqueName(serviceId);
        }
        else {
            service = await this.codestore.Service.getService(serviceId);
        }
        if (!service) {
            this.log(`You've tried to download the service with ${chalk_1.yellowBright(`ID = ${serviceId}`)}, but there is no service with this ID!
 Check again by listing services you have using ${chalk_1.yellow(' codestore service:list ')} command, then try again.

 If you still experience this error, ping us in our community here: ${chalk_1.blue('https://spectrum.chat/code-store')}`);
            return;
        }
        if (!confirmed) {
            confirmed = (await inquirer_1.default.prompt([
                {
                    name: 'confirmed',
                    message: `You're about to download service with ID = ${service.uniqueName} to your local machine. All local changes, if any, will be overwritten. Go?`,
                    type: 'confirm',
                    default: false,
                },
            ])).confirmed;
        }
        if (confirmed) {
            const data = await this.codestore.Service.download(service.id);
            await file_worker_1.default.saveZipFromB64(data, process.cwd());
            this.log(`Service ${chalk_1.blue(`with ID = ${service.uniqueName}`)} was downloaded successfully!`);
        }
    }
}
exports.default = Pull;
Pull.description = 'Download an existing service';
Pull.flags = Object.assign(Object.assign({}, command_2.default.flags), { force: command_1.flags.boolean({
        char: 'f',
        default: false,
    }) });
Pull.aliases = [aliases_1.default.PULL];
Pull.args = [
    { name: 'service_id', description: 'ID of the service (optional, if you\'re inside service folder)' },
];
