"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const command_1 = require("@oclif/command");
const chalk_1 = require("chalk");
const inquirer_1 = tslib_1.__importDefault(require("inquirer"));
const listr2_1 = require("listr2");
const command_2 = tslib_1.__importDefault(require("../../lib/command"));
class Remove extends command_2.default {
    async execute() {
        const data = this.parse(Remove);
        let { args: { service_id: serviceId } } = data;
        let confirmed = data.flags.force;
        if (!serviceId) {
            serviceId = (await this.serviceWorker.loadValuesFromYaml()).serviceId;
        }
        if (!confirmed) {
            confirmed = (await inquirer_1.default.prompt([
                {
                    name: 'result',
                    message: `Are you sure you want to delete the service with id ${serviceId}`,
                    type: 'confirm',
                    default: false,
                },
            ])).result;
        }
        if (confirmed) {
            const tasks = new listr2_1.Listr([{
                    title: `Removing service ${chalk_1.yellow(serviceId)}`,
                    task: async (ctx, task) => {
                        const isUniqueName = Number.isNaN(serviceId);
                        if (isUniqueName) {
                            await this.codestore.Service.deleteByUniqueName(serviceId);
                        }
                        else {
                            await this.codestore.Service.delete(serviceId);
                        }
                        task.title = 'Service was successfully removed';
                    },
                }]);
            await tasks.run();
        }
    }
}
exports.default = Remove;
Remove.description = 'Remove a service';
Remove.args = [
    { name: 'service_id', description: 'ID of the service (optional, if you\'re inside service folder)' },
];
Remove.flags = Object.assign(Object.assign({}, command_2.default.flags), { force: command_1.flags.boolean({
        char: 'f',
        default: false,
    }) });
