"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const command_1 = require("@oclif/command");
const cli_ux_1 = tslib_1.__importDefault(require("cli-ux"));
const command_2 = tslib_1.__importDefault(require("../lib/command"));
const environment_enum_1 = tslib_1.__importStar(require("./constants/environment.enum"));
class BaseSecretCommand extends command_2.default {
    static renderSecrets(secrets) {
        cli_ux_1.default.table(Object.keys(secrets).map((k) => ({ key: k, value: secrets[k].value, source: secrets[k].source })), {
            key: {},
            value: {},
            source: {},
        }, { 'no-truncate': true });
    }
    static isSecretCommandValid(projectUniqueName, serviceUniqueName, environment) {
        if (serviceUniqueName && !environment) {
            throw new Error('Please, specify environment using -e flag');
        }
        if (!projectUniqueName && !serviceUniqueName) {
            throw new Error('Please, specify project ID using -p flag or service ID using -s flag');
        }
        if (environment_enum_1.projectServiceEnvironments.includes(environment) && !projectUniqueName) {
            throw new Error(`Please, specify project ID using -p flag for ${environment} environment.`);
        }
        if (environment_enum_1.serviceEnvironments.includes(environment) && projectUniqueName) {
            throw new Error(`You can't add secret to ${environment} environment. Please, use one of project environment ${Object.values(environment_enum_1.projectServiceEnvironments)}`);
        }
    }
    // eslint-disable-next-line @typescript-eslint/no-empty-function
    async execute() {
    }
}
exports.default = BaseSecretCommand;
BaseSecretCommand.defaultFlags = Object.assign(Object.assign({}, command_2.default.flags), { projectUniqueName: command_1.flags.string({
        char: 'p',
        description: 'Project ID',
    }), environment: command_1.flags.enum({
        char: 'e',
        description: 'Project or service environment.',
        options: Object.values(environment_enum_1.default),
    }), serviceUniqueName: command_1.flags.string({
        char: 's',
        description: 'Service ID',
    }) });
