"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const codestore_utils_1 = require("codestore-utils");
const path_1 = require("path");
const fs = tslib_1.__importStar(require("fs"));
const child_process_1 = tslib_1.__importDefault(require("child_process"));
class GolangLauncher {
    constructor(database, port = 3000) {
        var _a, _b, _c, _d, _e;
        this.database = database;
        this.port = port;
        this.valuesToReplace = {
            PORT: this.port.toString(),
            DATABASE_NAME: (_a = this.database) === null || _a === void 0 ? void 0 : _a.database,
            DATABASE_USER: (_b = this.database) === null || _b === void 0 ? void 0 : _b.username,
            DATABASE_PWD: (_c = this.database) === null || _c === void 0 ? void 0 : _c.password,
            DATABASE_HOST: (_d = this.database) === null || _d === void 0 ? void 0 : _d.host,
            DATABASE_PORT: (_e = this.database) === null || _e === void 0 ? void 0 : _e.port.toString(),
        };
    }
    async bootstrap() {
        codestore_utils_1.logger.log('Validating schema', 'GraphQL');
        await codestore_utils_1.GraphqlValidatorTool.validateSchema();
        codestore_utils_1.logger.log('Generating launcher file', 'Go');
        this.initLauncherFile();
        try {
            codestore_utils_1.logger.log('Installing dependencies', 'Go');
            this.exec('go mod download all');
            codestore_utils_1.logger.log('Generating GraphQL runtime', 'Go');
            this.exec('gqlgen generate .');
            codestore_utils_1.logger.log('Starting local server', 'Go');
            this.exec('go run .');
        }
        catch (error) {
            // @haletsky:
            // Printing errors is handled by `stdio: inherit` in GolangLauncher.exec method
        }
    }
    exec(cmd) {
        child_process_1.default.execSync(cmd, { stdio: 'inherit', encoding: 'utf8' });
    }
    initLauncherFile() {
        const templatePath = path_1.resolve(__dirname, './template/main.go');
        const launcherPath = path_1.resolve(process.cwd(), 'main_gen.go');
        let launcher = fs.readFileSync(templatePath).toString();
        Object.keys(this.valuesToReplace).forEach((key) => {
            launcher = launcher.replace(`{{${key}}}`, this.valuesToReplace[key]);
        });
        fs.writeFileSync(launcherPath, launcher);
    }
}
exports.default = GolangLauncher;
