"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const codestore_utils_1 = require("codestore-utils");
const fs = tslib_1.__importStar(require("fs"));
const child_cli_1 = require("../../../lib/child-cli");
const resolver_validator_1 = tslib_1.__importDefault(require("../../resolver-validator"));
class TypescriptLauncher {
    constructor(watch = false, database, port = 3000) {
        this.watch = watch;
        this.database = database;
        this.port = port;
    }
    async bootstrap() {
        let close;
        codestore_utils_1.logger.log('Installing dependencies', 'NPM');
        await child_cli_1.installDependencies();
        codestore_utils_1.logger.log('Compiling typescript code', 'TypeScript');
        await codestore_utils_1.compile(await codestore_utils_1.PathsResolverTool.loadFilesToCompile());
        codestore_utils_1.logger.log('Validating schema', 'GraphQL');
        await codestore_utils_1.GraphqlValidatorTool.validateSchema();
        codestore_utils_1.logger.log('Validating queries and mutations', 'GraphQL');
        const validationData = await codestore_utils_1.GraphqlValidatorTool.validateQueriesAndMutations();
        if (await resolver_validator_1.default(validationData)) {
            codestore_utils_1.logger.log('Recompiling resolvers', 'TypeScript');
            await codestore_utils_1.compile(await codestore_utils_1.PathsResolverTool.loadFilesToCompile());
        }
        codestore_utils_1.logger.log('Starting development server', 'INFO');
        close = await codestore_utils_1.bootstrap();
        if (this.watch) {
            codestore_utils_1.logger.log('Starting compilation in watch mode', 'INFO');
            const waitBeforeRebootstrap = 2000;
            let timeout;
            const rebootstrap = async () => {
                codestore_utils_1.logger.log('Compiling typescript code', 'TypeScript');
                await codestore_utils_1.compile(await codestore_utils_1.PathsResolverTool.loadFilesToCompile());
                if (close)
                    await close();
                close = await codestore_utils_1.bootstrap(true);
            };
            fs.watch(codestore_utils_1.PathsResolverTool.SRC, { recursive: true }, async () => {
                clearTimeout(timeout);
                timeout = setTimeout(rebootstrap, waitBeforeRebootstrap);
            });
        }
    }
}
exports.default = TypescriptLauncher;
