"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const inquirer_1 = tslib_1.__importDefault(require("inquirer"));
const resolver_type_enum_1 = tslib_1.__importDefault(require("./constants/resolver-type.enum"));
const file_generator_1 = tslib_1.__importDefault(require("../lib/file-generator"));
const messageStrategies = {
    [resolver_type_enum_1.default.QUERY]: 'queries',
    [resolver_type_enum_1.default.MUTATION]: 'mutations',
};
const tryCreate = async (notExistedResolvers, resolverType) => {
    if (!notExistedResolvers.length) {
        return false;
    }
    const name = messageStrategies[resolverType];
    const message = `It looks like you are missing resolvers for the following ${name}: ${notExistedResolvers}
  Would you like us to create the following resolvers?
  \n${notExistedResolvers.map((it) => `-> src/resolvers/${name}/${it}.ts`).join('\n')}
  `;
    const { proceed } = await inquirer_1.default.prompt([
        {
            name: 'proceed',
            message,
            type: 'confirm',
        },
    ]);
    if (proceed) {
        const generators = notExistedResolvers.map((query) => new file_generator_1.default(resolverType, query).generate());
        await Promise.all(generators);
        return true;
    }
    throw new Error(`Failed to start, following ${name} ${notExistedResolvers} is defined in Schema but resolvers cannot be found.`);
};
exports.default = async ({ queries, mutations }) => {
    const queryCreationResult = await tryCreate(queries, resolver_type_enum_1.default.QUERY);
    const mutationCreationResult = await tryCreate(mutations, resolver_type_enum_1.default.MUTATION);
    return queryCreationResult || mutationCreationResult;
};
