"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const archiver_1 = tslib_1.__importDefault(require("archiver"));
const fs_1 = require("fs");
const codestore_utils_1 = require("codestore-utils");
const path_1 = require("path");
class Archiver {
    constructor(path) {
        this.path = path;
        this.zipName = 'temporaryUpload.zip';
        this.excludeFiles = ['node_modules', '.DS_Store', this.zipName, 'dist', '.git', '.gitignore'];
        this.absolutePath = path_1.join(this.path, this.zipName);
        this.archive = archiver_1.default('zip', { zlib: { level: 9 } });
        this.output = fs_1.createWriteStream(this.absolutePath);
    }
    async zipFiles(exclude) {
        if (exclude) {
            this.excludeFiles = [...this.excludeFiles, ...exclude];
        }
        await this.addItems();
        await this.archive.finalize();
        return new Promise((resolve, reject) => {
            this.output.on('error', (error) => reject(error));
            this.output.on('close', () => resolve(this.absolutePath));
            this.archive.pipe(this.output);
        });
    }
    async addItems() {
        const filesAndFolders = await codestore_utils_1.PromisifiedFs.readdir(process.cwd());
        const result = filesAndFolders.map(async (item) => {
            if (this.excludeFiles.find((element) => element === item)) {
                return;
            }
            const stat = await codestore_utils_1.PromisifiedFs.stat(item);
            if (stat.isFile()) {
                this.archive.file(item, { name: item });
            }
            else {
                this.archive.directory(item, item);
            }
        });
        await Promise.all(result);
    }
}
exports.default = Archiver;
