"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const database_1 = tslib_1.__importDefault(require("./api-services/database"));
const deployment_1 = tslib_1.__importDefault(require("./api-services/deployment"));
const logs_1 = tslib_1.__importDefault(require("./api-services/logs"));
const project_1 = tslib_1.__importDefault(require("./api-services/project"));
const secret_1 = tslib_1.__importDefault(require("./api-services/secret"));
const service_1 = tslib_1.__importDefault(require("./api-services/service"));
const user_1 = tslib_1.__importDefault(require("./api-services/user"));
const auth_1 = tslib_1.__importDefault(require("./api-services/auth"));
const webAuthHelper_1 = require("./webAuthHelper");
const git_providers_1 = tslib_1.__importDefault(require("./api-services/git-providers"));
class APIClient {
    constructor(homeFolderService, graphqlClient, verbose) {
        this.homeFolderService = homeFolderService;
        this.graphqlClient = graphqlClient;
        this.Database = new database_1.default(this.graphqlClient, verbose);
        this.Deployment = new deployment_1.default(this.graphqlClient, verbose);
        this.Logs = new logs_1.default(this.graphqlClient, verbose);
        this.Project = new project_1.default(this.graphqlClient, verbose);
        this.Secret = new secret_1.default(this.graphqlClient, verbose);
        this.Service = new service_1.default(this.graphqlClient, verbose);
        this.User = new user_1.default(this.graphqlClient, verbose);
        this.Auth = new auth_1.default(this.graphqlClient, verbose);
        this.GitProviders = new git_providers_1.default(this.graphqlClient, verbose);
    }
    async loginWeb(device) {
        await this.homeFolderService.removeTokens();
        // opening browser. See openBrowser.ts for change configurations
        await webAuthHelper_1.openBrowser(device);
        return new Promise((resolve, reject) => {
            // launching local server to get redirect from authentication service.
            webAuthHelper_1.server.listen(10999);
            // waiting for auth event was emitted to set token/show error and close server
            webAuthHelper_1.emitter.on('auth', (result) => {
                const { success, accessToken, refreshToken, error, } = result;
                if (success) {
                    this.homeFolderService.saveTokens(accessToken, refreshToken)
                        .then(() => webAuthHelper_1.server.close(() => resolve()))
                        .catch((e) => webAuthHelper_1.server.close(() => reject(e)));
                }
                else {
                    webAuthHelper_1.server.close(() => reject(error));
                }
            });
        });
    }
    async loginWithEmailAndPassword(email, password, device) {
        await this.homeFolderService.removeTokens();
        const { refreshToken, accessToken } = await this.Auth.login(email, password, device);
        await this.homeFolderService.saveTokens(refreshToken, accessToken);
    }
    async logout() {
        return this.homeFolderService.removeTokens();
    }
}
exports.default = APIClient;
