"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const errors_1 = require("../errors");
class ApiService {
    constructor(apiClient, logger) {
        this.apiClient = apiClient;
        this.logger = logger;
        this.errors = new Map([
            ['Unauthorized', new errors_1.NotAuthorizedError()],
            ['Bad JWT token.', new errors_1.NotAuthorizedError()],
            ['Unauthorized on selected provider', new errors_1.GitNotAuthorizedError()],
        ]);
    }
    static getQuery(doc) {
        var _a, _b;
        return (_b = (_a = doc === null || doc === void 0 ? void 0 : doc.loc) === null || _a === void 0 ? void 0 : _a.source) === null || _b === void 0 ? void 0 : _b.body;
    }
    handleCustomError(message) {
        const error = this.errors.get(message);
        if (error) {
            return error;
        }
        return new Error(message);
    }
    async executeQuery(query, variables) {
        var _a, _b;
        const logQuery = ApiService.getQuery(query);
        await this.logger.logRequest(`${logQuery}`, variables);
        try {
            const result = await this.apiClient.query({
                query,
                variables,
                fetchPolicy: 'no-cache',
            });
            this.logger.logResult(logQuery, result);
            return result;
        }
        catch (e) {
            this.logger.logError(logQuery, e);
            if ((_a = e.graphQLErrors) === null || _a === void 0 ? void 0 : _a.length) {
                throw this.handleCustomError((_b = e.graphQLErrors[0]) === null || _b === void 0 ? void 0 : _b.message);
            }
            throw this.handleCustomError(e.message);
        }
    }
    async executeMutation(mutation, variables) {
        var _a;
        const query = ApiService.getQuery(mutation);
        await this.logger.logRequest(`${query}`, variables);
        try {
            const data = await this.apiClient.mutate({
                mutation,
                variables,
            });
            this.logger.logResult(query, data);
            return data;
        }
        catch (e) {
            this.logger.logError(query, e);
            if ((_a = e.graphQLErrors) === null || _a === void 0 ? void 0 : _a.length) {
                throw this.handleCustomError(e.graphQLErrors[0].message);
            }
            throw this.handleCustomError(e.message);
        }
    }
}
exports.default = ApiService;
