"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const queries = tslib_1.__importStar(require("./queries"));
const base_api_service_1 = tslib_1.__importDefault(require("../base-api-service"));
const deployment_status_enum_1 = tslib_1.__importDefault(require("../../../common/constants/deployment-status.enum"));
class Deployment extends base_api_service_1.default {
    async getDeployment(serviceId, environmentName, projectId) {
        const { data } = await this.executeQuery(queries.GET_DEPLOYMENT, {
            serviceId,
            environmentName,
            projectId,
        });
        return data.deploymentByProjectServiceAndEnvironment;
    }
    async getDeploymentsForService(serviceId) {
        const { data } = await this.executeQuery(queries.GET_DEPLOYMENTS_FOR_SERVICE, {
            serviceId,
        });
        return data.deploymentsForService;
    }
    async getDeploymentsForServices(serviceIds) {
        const { data } = await this.executeQuery(queries.GET_DEPLOYMENTS_FOR_SERVICES, {
            serviceIds,
        });
        return data.deploymentsForServices;
    }
    async getDeploymentsForProjectService(projectId, serviceId) {
        const { data } = await this.executeQuery(queries.GET_DEPLOYMENTS_FOR_PROJECT_SERVICE, {
            projectId,
            serviceId,
        });
        return data.deploymentsForProjectService;
    }
    async checkDeployment(serviceId, environmentName, projectId) {
        return new Promise((resolve, reject) => {
            const interval = setInterval(async () => {
                const clear = (error) => {
                    if (error) {
                        reject(new Error(error));
                    }
                    else {
                        resolve(true);
                    }
                    clearInterval(interval);
                };
                const service = await this.getDeployment(serviceId, environmentName, projectId);
                if (!(service === null || service === void 0 ? void 0 : service.status)) {
                    clear('Failed to retrieve the deployment');
                }
                if (service.status === deployment_status_enum_1.default.DEPLOYMENT_FAILED) {
                    clear('Deployment has failed');
                }
                if (service.status === deployment_status_enum_1.default.DEPLOYED) {
                    clear();
                }
            }, 3000);
        });
    }
}
exports.default = Deployment;
