"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const apollo_boost_1 = require("apollo-boost");
const queries_1 = require("./queries");
const base_api_service_1 = tslib_1.__importDefault(require("../base-api-service"));
class Project extends base_api_service_1.default {
    constructor() {
        super(...arguments);
        this.transformProjectService = (project) => {
            var _a;
            return (Object.assign(Object.assign({}, project), { services: (_a = project.projectServices) === null || _a === void 0 ? void 0 : _a.map((ps) => ps.service) }));
        };
    }
    async create(data) {
        const { data: { createProject } } = await this.executeMutation(queries_1.CREATE_PROJECT, { data });
        return createProject;
    }
    async delete(id) {
        const { data } = await this.executeMutation(queries_1.DELETE_PROJECT, { id });
        return data;
    }
    async deleteByUniqueName(uniqueName) {
        const { data } = await this.executeMutation(queries_1.DELETE_PROJECT_BY_UNIQUE_NAME, { uniqueName });
        return data;
    }
    async list() {
        const { data: { projects } } = await this.executeQuery(queries_1.LIST_PROJECTS, {
            pagination: {
                page: 1,
                perPage: 100,
            },
        });
        return projects.map(this.transformProjectService);
    }
    async singleByUniqueName(uniqueName, includeServices = false) {
        const query = includeServices ? queries_1.SINGLE_PROJECT_INCLUDE_SERVICES_BY_UNIQUE_NAME : queries_1.SINGLE_PROJECT_BY_UNIQUE_NAME;
        const { data: { project } } = await this.executeQuery(query, { uniqueName });
        return this.transformProjectService(project);
    }
    async single(id, includeServices = false) {
        const query = includeServices ? queries_1.SINGLE_PROJECT_INCLUDE_SERVICES : queries_1.SINGLE_PROJECT;
        const { data: { project } } = await this.executeQuery(query, { id });
        return this.transformProjectService(project);
    }
    async includeServiceByUniqueName(projectUniqueName, serviceUniqueName, billingType, billingValue) {
        const mutation = apollo_boost_1.gql `mutation includeServiceByUniqueNames($data: InputProjectServiceUniqueNamesWithBilling!){
      includeServiceByUniqueNames(data: $data) {
        status
      }
    }`;
        const { data: { includeServiceByUniqueNames } } = await this.executeMutation(mutation, {
            data: {
                projectUniqueName,
                serviceUniqueName,
                billingType,
                billingValue,
            },
        });
        return includeServiceByUniqueNames;
    }
    async excludeServiceByUniqueName(projectUniqueName, serviceUniqueName) {
        const mutation = apollo_boost_1.gql `mutation excludeServiceByUniqueNames($data: InputProjectServiceUniqueNames!) {
      excludeServiceByUniqueNames(data: $data) {
        status
      }
    }`;
        const { data: { excludeServiceByUniqueNames } } = await this.executeMutation(mutation, {
            data: {
                projectUniqueName,
                serviceUniqueName,
            },
        });
        return excludeServiceByUniqueNames;
    }
    async singleWithEnvsByUniqueName(uniqueName) {
        const { data: { project } } = await this.executeQuery(queries_1.SINGLE_PROJECT_ENV_BY_UNIQUE_NAME, { uniqueName });
        return this.transformProjectService(project);
    }
    async singleWithEnvs(projectId) {
        const { data: { project } } = await this.executeMutation(queries_1.SINGLE_PROJECT_ENV, { id: projectId });
        return this.transformProjectService(project);
    }
    async roll(data) {
        const { data: { roll } } = await this.executeMutation(queries_1.ROLL, { data });
        return roll;
    }
    async promoteService(data) {
        const { data: { promoteServiceInProject } } = await this.executeMutation(queries_1.PROMOTE_SERVICE_IN_PROJECT, { data });
        return promoteServiceInProject;
    }
    async promoteServiceByUniqueName(data) {
        const { data: { promoteServiceInProjectByUniqueName } } = await this.executeMutation(queries_1.PROMOTE_SERVICE_IN_PROJECT_BY_UNIQUE_NAME, { data });
        return promoteServiceInProjectByUniqueName;
    }
    async createClientApiKey(projectId, email) {
        const { data: { createClientApiKey } } = await this.executeMutation(queries_1.CREATE_CLIENT_API_KEY, { projectId, email });
        return createClientApiKey;
    }
    async listClientsByUniqueName(uniqueName) {
        const { data: { project } } = await this.executeQuery(queries_1.LIST_CLIENTS, { uniqueName });
        return project === null || project === void 0 ? void 0 : project.clients;
    }
    async deleteClient(clientId) {
        const { data: { deleteClientApiKey } } = await this.executeQuery(queries_1.DELETE_CLIENT_API_KEY, { clientId });
        return deleteClientApiKey;
    }
}
exports.default = Project;
