"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const service_state_enum_1 = tslib_1.__importDefault(require("../../../common/constants/service-state.enum"));
const service_status_enum_1 = tslib_1.__importDefault(require("../../../common/constants/service-status.enum"));
const base_api_service_1 = tslib_1.__importDefault(require("../base-api-service"));
const queries = tslib_1.__importStar(require("./queries"));
class Service extends base_api_service_1.default {
    async list(includeDeployments) {
        const query = includeDeployments ? queries.LIST_SERVICE_INCLUDE_DEPLOYMENTS : queries.LIST_SERVICES;
        const { data: { services } } = await this.executeQuery(query, {
            pagination: {
                page: 1,
                perPage: 100,
            },
        });
        return services;
    }
    async create(service) {
        const { data: { createService } } = await this.executeMutation(queries.CREATE_SERVICE, { service });
        return createService;
    }
    async businessDomains() {
        const { data: { getBusinessDomains } } = await this.executeQuery(queries.LIST_BUSINESS_DOMAINS, null);
        return getBusinessDomains.map((domain) => domain.replace('_', ' '));
    }
    async delete(id) {
        const { data } = await this.executeMutation(queries.DELETE_SERVICE, {
            id: {
                id,
            },
        });
        return data;
    }
    async deleteByUniqueName(uniqueName) {
        const { data } = await this.executeMutation(queries.DELETE_SERVICE_BY_UNIQUE_NAME, { uniqueName });
        return data;
    }
    async download(id) {
        const result = await this.executeQuery(queries.DOWNLOAD_SERVICE, { id });
        return result.data.downloadProject.data;
    }
    async downloadByUniqueName(uniqueName) {
        const result = await this.executeQuery(queries.DOWNLOAD_SERVICE_BY_UNIQUE_NAME, { uniqueName });
        return result.data.downloadProject.data;
    }
    async push(encodedString, releaseNotes, description) {
        const { data: { pushService } } = await this.executeMutation(queries.PUSH_SERVICE, {
            base64Service: encodedString,
            notes: releaseNotes,
            description,
        });
        return pushService;
    }
    async getServiceByUniqueName(uniqueName) {
        const { data: { serviceByUniqueName } } = await this.executeQuery(queries.SINGLE_SERVICE_BY_UNIQUE_NAME, { uniqueName });
        return serviceByUniqueName;
    }
    async getService(serviceId, includeDeployments) {
        const query = includeDeployments ? queries.SINGLE_SERVICE_INCLUDING_DEPLOYMENTS : queries.SINGLE_SERVICE;
        const { data: { service } } = await this.executeQuery(query, { id: serviceId });
        return service;
    }
    async checkServiceCreated(serviceId) {
        return new Promise((resolve) => {
            const interval = setInterval(async () => {
                const service = await this.getService(serviceId);
                if (service.state === service_state_enum_1.default.NEW_CONTAINER_IMAGE_AVAILABLE) {
                    resolve(true);
                    clearInterval(interval);
                }
            }, 3000);
        });
    }
    async checkServiceDeployed(serviceId) {
        return new Promise((resolve) => {
            const interval = setInterval(async () => {
                const service = await this.getService(serviceId);
                if (service.status === service_status_enum_1.default.ACTIVE) {
                    resolve(true);
                    clearInterval(interval);
                }
            }, 3000);
        });
    }
    async generateEntities(schema) {
        const { data: { generateServiceEntities } } = await this.executeMutation(queries.GENERATE_SERVICE_ENTITIES, {
            schema,
        });
        return generateServiceEntities;
    }
    async promoteByUniqueName(uniqueName) {
        const { data: { promoteServiceByUniqueName } } = await this.executeMutation(queries.PROMOTE_SERVICE_BY_UNIQUE_NAME, { uniqueName });
        return promoteServiceByUniqueName;
    }
    async promote(serviceId) {
        const { data: { promoteService } } = await this.executeMutation(queries.PROMOTE_SERVICE, { id: serviceId });
        return promoteService;
    }
    async isUniqueNameAvailable(displayName) {
        const { data: { isServiceUniqueNameAvailable } } = await this.executeQuery(queries.IS_SERVICE_UNIQUE_NAME_AVAILABLE, { displayName });
        return isServiceUniqueNameAvailable;
    }
    async compareSchemas(schema, serviceId) {
        const { data: { compareSchemas } } = await this.executeQuery(queries.COMPARE_SCHEMAS, { schema, serviceId });
        return compareSchemas;
    }
}
exports.default = Service;
