"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.COMPARE_SCHEMAS = exports.IS_SERVICE_UNIQUE_NAME_AVAILABLE = exports.GET_SERVICE_MIGRATIONS = exports.GENERATE_SERVICE_ENTITIES = exports.PROMOTE_SERVICE = exports.PROMOTE_SERVICE_BY_UNIQUE_NAME = exports.PUSH_SERVICE = exports.DOWNLOAD_SERVICE = exports.DOWNLOAD_SERVICE_BY_UNIQUE_NAME = exports.DELETE_SERVICE = exports.DELETE_SERVICE_BY_UNIQUE_NAME = exports.DEPLOY_SERVICE = exports.LIST_BUSINESS_DOMAINS = exports.CREATE_SERVICE = exports.SINGLE_SERVICE_INCLUDING_DEPLOYMENTS = exports.SINGLE_SERVICE = exports.SINGLE_SERVICE_BY_UNIQUE_NAME = exports.LIST_SERVICE_INCLUDE_DEPLOYMENTS = exports.LIST_SERVICES = void 0;
const apollo_boost_1 = require("apollo-boost");
const fields_1 = require("../fields");
exports.LIST_SERVICES = apollo_boost_1.gql `query s($pagination:PaginationOptions){
    services(pagination:$pagination, isPrivate: true){
        ${fields_1.SERVICE}
    }
}`;
exports.LIST_SERVICE_INCLUDE_DEPLOYMENTS = apollo_boost_1.gql `query s($pagination:PaginationOptions){
  services(pagination:$pagination, isPrivate: true){
    ${fields_1.SERVICE}
    deployments {
      ${fields_1.DEPLOYMENT}
    }
  }
}`;
exports.SINGLE_SERVICE_BY_UNIQUE_NAME = apollo_boost_1.gql `query serviceByUniqueName($uniqueName: String!) {
  serviceByUniqueName(uniqueName: $uniqueName) {
    ${fields_1.SERVICE}
  }
}`;
exports.SINGLE_SERVICE = apollo_boost_1.gql `query singleService($id: Int!){
  service(id:{
    id: $id
  }){
    ${fields_1.SERVICE}
    deployments {
      ${fields_1.DEPLOYMENT}
    }
  }
}`;
exports.SINGLE_SERVICE_INCLUDING_DEPLOYMENTS = apollo_boost_1.gql `query singleService($id: Int!){
  service(id:{
    id: $id
  }){
    ${fields_1.SERVICE}
    deployments {
      ${fields_1.DEPLOYMENT}
    }
  }
}`;
exports.CREATE_SERVICE = apollo_boost_1.gql `
    mutation createService(
        $service: CreateService!,
    ){
        createService(service:$service){
           service {
             ${fields_1.SERVICE}
           }
           commitId
        }
    }`;
exports.LIST_BUSINESS_DOMAINS = apollo_boost_1.gql `{
    getBusinessDomains
}`;
exports.DEPLOY_SERVICE = apollo_boost_1.gql `mutation deployService($deployment: DeploymentCreate!){
    deployService(deployment:$deployment){
        ${fields_1.SERVICE}
    }
}`;
exports.DELETE_SERVICE_BY_UNIQUE_NAME = apollo_boost_1.gql `mutation deleteServiceByUniqueName($uniqueName: String!) {
    deleteServiceByUniqueName(uniqueName:$uniqueName) { id }
}`;
exports.DELETE_SERVICE = apollo_boost_1.gql `mutation deleteService($id: Id!){
    deleteService(id:$id){
        affected
    }
}`;
exports.DOWNLOAD_SERVICE_BY_UNIQUE_NAME = apollo_boost_1.gql `query downloadProjectByUniqueName($uniqueName: String!) {
  downloadProjectByUniqueName(uniqueName: $uniqueName) {
    data
  }
}`;
exports.DOWNLOAD_SERVICE = apollo_boost_1.gql `query downloadProject($id: Int!){
  downloadProject(serviceId:$id){
    data
  }
}`;
exports.PUSH_SERVICE = apollo_boost_1.gql `mutation pushService($base64Service: String!, $notes: [String]!, $description: String!) {
  pushService(base64Service:$base64Service, releaseNotes: $notes, description: $description)
}`;
exports.PROMOTE_SERVICE_BY_UNIQUE_NAME = apollo_boost_1.gql `mutation promoteServiceByUniqueName($uniqueName: String!) {
  promoteServiceByUniqueName(uniqueName: $uniqueName) {
    ${fields_1.SERVICE}
  }
}`;
exports.PROMOTE_SERVICE = apollo_boost_1.gql `mutation promoteService($id: Int!){
  promoteService(id: $id){
    ${fields_1.SERVICE}
  }
}`;
exports.GENERATE_SERVICE_ENTITIES = apollo_boost_1.gql `mutation generateServiceEntities($schema: String!){
  generateServiceEntities(schema:$schema) {
    data
    logs
  }
}`;
exports.GET_SERVICE_MIGRATIONS = apollo_boost_1.gql `query getServiceMigrations($base64Service: String!){
  getServiceMigrations(base64Service:$base64Service){
    data
  }
}`;
exports.IS_SERVICE_UNIQUE_NAME_AVAILABLE = apollo_boost_1.gql `query isServiceUniqueNameAvailable($displayName: String!) {
  isServiceUniqueNameAvailable(displayName:$displayName){
    uniqueName
    free
    variants
  }
}`;
exports.COMPARE_SCHEMAS = apollo_boost_1.gql `query compareSchemas($schema: String!, $serviceId: Int!) {
  compareSchemas(schema:$schema, serviceId: $serviceId){
    message
    type
    criticalityLevel
  }
}`;
