"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.validateCodestoreConfig = exports.schema = void 0;
const tslib_1 = require("tslib");
const joi_1 = tslib_1.__importDefault(require("joi"));
const template_enum_1 = tslib_1.__importDefault(require("../common/constants/template.enum"));
exports.schema = joi_1.default.object({
    serviceId: joi_1.default.number().required(),
    template: joi_1.default.string().allow(...Object.values(template_enum_1.default)).default(template_enum_1.default.Typescript),
    serviceConfiguration: joi_1.default.object({
        skipDatabase: joi_1.default.boolean().default(false),
        enableRedis: joi_1.default.boolean().default(false),
    }),
    localConfiguration: joi_1.default.object({
        database: joi_1.default.object({
            host: joi_1.default.string().required(),
            port: joi_1.default.number().required(),
            database: joi_1.default.string().required(),
            username: joi_1.default.string().required(),
            password: joi_1.default.string().required(),
        }),
        application: joi_1.default.object({
            port: joi_1.default.number().required(),
        }).required(),
        redis: joi_1.default.object({
            host: joi_1.default.string().required(),
            port: joi_1.default.number().default(3000),
        }),
    })
        .when('serviceConfiguration.skipDatabase', { is: false, then: { database: joi_1.default.required() } })
        .when('serviceConfiguration.enableRedis', { is: true, then: { redis: joi_1.default.required() } }),
});
exports.validateCodestoreConfig = (config) => {
    const v = exports.schema.validate(config, { abortEarly: false });
    // eslint-disable-next-line @typescript-eslint/no-throw-literal
    if (v.error || v.errors)
        throw (v.error || v.errors);
    return v.value;
};
