import { Command as Base, flags } from '@oclif/command';
import ApolloClient from 'apollo-boost';
import IProject from '../interfaces/project.interface';
import IService from '../interfaces/service.interface';
import APIClient from './api-client';
import ServiceWorker from './service-worker';
import VerboseLogger from './verbose-logger';
import EnvironmentEnum from '../common/constants/environment.enum';
import IVersion from '../interfaces/version.interface';
export default abstract class Command extends Base {
    static flags: {
        verbose: import("@oclif/parser/lib/flags").IBooleanFlag<boolean>;
        verbosePath: flags.IOptionFlag<string | undefined>;
    };
    protected verboseLogger: VerboseLogger;
    private homeFolderService;
    serviceWorker: ServiceWorker;
    base: string;
    private _codestore;
    protected gqlClient: ApolloClient<unknown>;
    protected get rules(): {
        [key: string]: (value: any, allValues?: Object) => string | boolean | Promise<string | boolean>;
    };
    static apiPath: string;
    static appPath: string;
    private authToken;
    get codestore(): APIClient;
    abstract execute(): PromiseLike<any>;
    run(): Promise<void>;
    private refreshToken;
    private setupApiClient;
    protected resetApiClient(): Promise<void>;
    protected renderTable(data: object[], schema: any, options?: object): void;
    protected findService(serviceName: string, inputServices?: IService[]): Promise<IService | undefined>;
    protected chooseService(args: {
        [key: string]: string;
    }, prefix?: string, inputServices?: IService[]): Promise<IService | undefined>;
    protected chooseVersion(service: IService): Promise<IVersion>;
    protected chooseEnvironment(choices: Map<string, EnvironmentEnum> | string[], message?: string): Promise<EnvironmentEnum>;
    protected findProject(projectName: string, inputProjects?: IProject[]): Promise<IProject | undefined>;
    protected chooseProject(args: {
        [key: string]: string;
    }, prefix?: string, withEmptySlot?: boolean): Promise<IProject | undefined>;
    static getServiceUrl({ endpoint }: {
        endpoint: string;
    }): string;
    protected validate(fieldName: string, fieldValue: string | undefined | boolean, flagsData?: Object): Promise<string | boolean>;
    protected validateFlags<T>(flagsOptions: T, flagsData: {
        [key: string]: string | undefined | boolean;
    }): Promise<{
        [key in keyof T]: string;
    }>;
    protected flagsLength(flagsData: any): boolean;
}
