"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const command_1 = require("@oclif/command");
const chalk_1 = require("chalk");
const environment_enum_1 = tslib_1.__importStar(require("../common/constants/environment.enum"));
const command_2 = tslib_1.__importDefault(require("./command"));
class DbCommand extends command_2.default {
    get rules() {
        return {
            environment: (value, data) => {
                if (!value) {
                    return true;
                }
                if (data.project && !environment_enum_1.projectServiceEnvironments.includes(value)) {
                    return `With specified project only the next environments are available: ${environment_enum_1.projectServiceEnvironments}`;
                }
                if (!data.project && !environment_enum_1.serviceEnvironments.includes(value)) {
                    return `Without specified project only the next environments are available: ${environment_enum_1.serviceEnvironments}`;
                }
                return true;
            },
        };
    }
    async execute() {
        return 0;
    }
    async getDb(flagsData) {
        const data = await this.validateFlags(DbCommand.flags, flagsData);
        let project = {};
        let projectServices;
        if (data.project) {
            project = (await this.chooseProject({ projectArg: data.project }));
            if (!project) {
                return undefined;
            }
            projectServices = project.projectServices.map((ps) => ps.service);
        }
        const { serviceId } = await this.serviceWorker.loadValuesFromYaml();
        let service = await this.codestore.Service.getService(serviceId);
        service = (await this.chooseService({ serviceArg: data.service || service.uniqueName }, '', projectServices));
        if (!service) {
            return undefined;
        }
        const environment = data.environment || (project.id ? environment_enum_1.default.DEVELOPMENT : environment_enum_1.default.PRIVATE);
        this.log(`You have choosed the DB for${project.id ? ` project ${chalk_1.blue(project.uniqueName)}` : ''} service ${chalk_1.blue(service.uniqueName)} on ${chalk_1.blue(environment)} environment`);
        return {
            environment,
            service,
            project,
        };
    }
}
exports.default = DbCommand;
DbCommand.flags = Object.assign(Object.assign({}, command_2.default.flags), { environment: command_1.flags.string({
        char: 'e',
        description: 'Environment',
        options: Object.values(environment_enum_1.default),
    }), service: command_1.flags.string({
        char: 's',
        description: 'Service ID',
    }), project: command_1.flags.string({
        char: 'p',
        description: 'Project ID',
    }) });
