"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const codestore_utils_1 = require("codestore-utils");
const strategy_1 = tslib_1.__importDefault(require("./strategy"));
class FileGenerator {
    constructor(strategy, name) {
        this.name = name;
        this.generatorStrategies = {
            mutation: new strategy_1.default('resolver.ts', '/resolvers/mutations'),
            query: new strategy_1.default('resolver.ts', '/resolvers/queries'),
            auth: new strategy_1.default('auth.handler.ts', '/resolvers'),
            context: new strategy_1.default('context.handler.ts', '/resolvers'),
            endpoint: new strategy_1.default('endpoint.ts', '/rest'),
            middleware: new strategy_1.default('middleware.ts', '/rest-middlewares'),
        };
        if (!Object.keys(this.generatorStrategies).includes(strategy)) {
            throw new Error(`${strategy} strategy not found`);
        }
        this.chosenStrategy = this.generatorStrategies[strategy];
        this.chosenStrategy.setName(name);
    }
    async generate() {
        await this.chosenStrategy.createRootIfNotExists();
        const buffer = await codestore_utils_1.PromisifiedFs.readFile(this.chosenStrategy.getTemplatePath());
        const path = this.chosenStrategy.getPathToFile();
        await codestore_utils_1.PromisifiedFs.writeFile(path, buffer);
        return path;
    }
    async isFileExists() {
        try {
            const path = this.chosenStrategy.getPathToFile();
            await codestore_utils_1.PromisifiedFs.access(path);
            return path;
        }
        catch (e) {
            return null;
        }
    }
}
exports.default = FileGenerator;
