"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const codestore_utils_1 = require("codestore-utils");
class VerboseLogger {
    constructor(shouldLog, path) {
        this.shouldLog = shouldLog;
        this.path = path;
        this.logsArray = [];
    }
    register(command) {
        this.logsArray.push(`\n ${new Date()} ${command} \n`);
        return this;
    }
    logRequest(query, data) {
        if (this.shouldLog) {
            const logMessage = `Querying ${query}`;
            codestore_utils_1.logger.log(logMessage, 'graphql', data);
            this.logsArray.push(`${logMessage}, data: ${JSON.stringify(data)}`);
        }
    }
    logResult(query, data) {
        if (this.shouldLog) {
            const message = `Result for ${query} - `;
            codestore_utils_1.logger.log(message, 'graphql', data);
            this.logsArray.push(`${message} ${JSON.stringify(data)}`);
        }
    }
    logError(query, error) {
        if (this.shouldLog) {
            const message = `Query ${query} failed with error ${error}`;
            this.logsArray.push(message);
        }
    }
    async pushToFile() {
        if (process.env.VERBOSE && this.shouldLog) {
            try {
                await codestore_utils_1.PromisifiedFs.access(this.path);
            }
            catch (e) {
                codestore_utils_1.logger.log(`${this.path} does not exists. Creating...`);
                await codestore_utils_1.PromisifiedFs.writeFile(this.path, '');
            }
            codestore_utils_1.logger.log(`Logs were saved to ${this.path}`);
            await codestore_utils_1.PromisifiedFs.append(this.path, `${this.logsArray.join('\n')}\n ####################`);
        }
    }
}
exports.default = VerboseLogger;
